@@ -106,4 +106,49 @@ MARKETS: list[Market] = [
         mainnet_pyth_oracle="8RMnV1eD55iqUFJLMguPkYBkq8DCtx81XcmAja93LvRR",
         # launch_ts: 1643686767000,
     ),
+    Market(
+        symbol="XRP-PERP",
+        base_asset_symbol="XRP",
+        market_index=13,
+        devnet_pyth_oracle="WMW5xc3HypXwTnPesyUT49uLsyHwNURsWAEk39onKuk",
+        mainnet_pyth_oracle="WMW5xc3HypXwTnPesyUT49uLsyHwNURsWAEk39onKuk",
+        # launchTs: 1647543166000,
+		# oracleSource: OracleSource.SWITCHBOARD,    
+    ),
+    Market(
+        symbol="APE-PERP",
+        base_asset_symbol="APE",
+        market_index=14,
+        devnet_pyth_oracle="AwH6kBrJbkL9JTeqRd7Q59EdWh6UjPtoqoA5M4x4K2fA",
+        mainnet_pyth_oracle="74zeQpprjNtEghGiC3VEPsR9y4kR2GTd4Rq9YVk9tnjz",
+        # launchTs: 1648475932000,
+		# oracleSource: OracleSource.SWITCHBOARD,    
+    ),
+    Market(
+        symbol="DOGE-PERP",
+        base_asset_symbol="DOGE",
+        market_index=15,
+        devnet_pyth_oracle="4L6YhY8VvUgmqG5MvJkUJATtzB2rFqdrJwQCmFLv4Jzy",
+        mainnet_pyth_oracle="FsSM3s38PX9K7Dn6eGzuE29S2Dsk1Sss1baytTQdCaQj",
+        # launchTs: 1648607439000,
+		# oracleSource: OracleSource.PYTH,    
+    ),
+    Market(
+        symbol="NEAR-PERP",
+        base_asset_symbol="NEAR",
+        market_index=16,
+        devnet_pyth_oracle="3gnSbT7bhoTdGkFVZc1dW1PvjreWzpUNUD5ppXwv1N59",
+        mainnet_pyth_oracle="ECSFWQ1bnnpqPVvoy9237t2wddZAaHisW88mYxuEHKWf",
+        # launchTs: 1649105516000,
+		# oracleSource: OracleSource.PYTH,    
+    ),
+     Market(
+        symbol="SRM-PERP",
+        base_asset_symbol="SRM",
+        market_index=17,
+        devnet_pyth_oracle="992moaMQKs32GKZ9dxi8keyM2bUmbrwBZpK4p2K6X5Vs",
+        mainnet_pyth_oracle="3NBReDRTLKMQEKiLD5tGcx4kXbTf88b7f2xLS9UuGjym",
+        # launchTs: 1649105516000,
+		# oracleSource: OracleSource.PYTH,
+    ),
 ]
